@@ -7,7 +7,6 @@ import (
 	"flag"
 	"fmt"
 	"io"
-	"io/ioutil"
 	"log"
 	"os"
 	"path/filepath"
@@ -194,7 +193,7 @@ func (cli Cli) Run(args []string) int {
 			trdsql.InPreRead(inPreRead),
 			trdsql.InJQ(inJQuery),
 		)
-		if err := trdsql.Analyze(analyze, opts, readOpts); err != nil {
+		if err = trdsql.Analyze(analyze, opts, readOpts); err != nil {
 			log.Printf("ERROR: %s", err)
 			return 1
 		}
@@ -292,7 +291,7 @@ func (cli Cli) Run(args []string) int {
 
 	ctx := context.Background()
 
-	if err := trd.ExecContext(ctx, query); err != nil {
+	if err = trd.ExecContext(ctx, query); err != nil {
 		log.Printf("%s", err)
 		return 1
 	}
@@ -427,7 +426,7 @@ func getQuery(args []string, fileName string) (string, error) {
 		return trimQuery(strings.Join(args, " ")), nil
 	}
 
-	sqlByte, err := ioutil.ReadFile(fileName)
+	sqlByte, err := os.ReadFile(fileName)
 	if err != nil {
 		return "", err
 	}
